/*
 * NASPRO - The NASPRO Architecture for Sound Processing
 * A collection of bridges to LV2
 * LADSPA bridge
 *
 * Copyright (C) 2007-2011 NASPRO bridges development team
 *
 * See the COPYING file for license conditions.
 */

NACORE_PRIVATE void
pluglib_load(void *value, void *opaque);

NACORE_PRIVATE void
pluglib_unload(void *value, void *opaque);
